@@ -33,7 +33,7 @@ GuiDialog::GuiDialog(int dummy)
 {
   Shortcuts shortcuts(0);
   gtkbuilder = gtk_builder_new ();
-  gtk_builder_add_from_file (gtkbuilder, gw_build_filename (directories_get_package_data(), "gtkbuilder.guidialog.xml").c_str(), NULL);
+  gtk_builder_add_from_file (gtkbuilder, gw_build_filename (Directories->get_package_data(), "gtkbuilder.guidialog.xml").c_str(), NULL);
   featuresdialog = GTK_WIDGET (gtk_builder_get_object (gtkbuilder, "guidialog"));
   radiobutton_basic = GTK_WIDGET (gtk_builder_get_object (gtkbuilder, "radiobutton_basic"));
   shortcuts.button(radiobutton_basic);
