@@ -1,5 +1,5 @@
 /*
-** Copyright (©) 2003-2012 Teus Benschop.
+** Copyright (©) 2003-2013 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -162,12 +162,6 @@ MyChecksDialog::MyChecksDialog(WindowReferences * references_window)
 
   shortcuts.button(checkbutton_punctuation_matching_pairs);
 
-  checkbutton_punctuation_sentence_structure = gtk_check_button_new_with_mnemonic("Sentence structure");
-  gtk_widget_show(checkbutton_punctuation_sentence_structure);
-  gtk_box_pack_start(GTK_BOX(vbox1), checkbutton_punctuation_sentence_structure, FALSE, FALSE, 0);
-
-  shortcuts.button(checkbutton_punctuation_sentence_structure);
-
   hseparator5 = gtk_hseparator_new();
   gtk_widget_show(hseparator5);
   gtk_box_pack_start(GTK_BOX(vbox1), hseparator5, TRUE, TRUE, 0);
@@ -233,7 +227,6 @@ MyChecksDialog::MyChecksDialog(WindowReferences * references_window)
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbutton_markers_spacing), bitpattern_take(pattern));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbutton_references_inventory), bitpattern_take(pattern));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbutton_references_validate), bitpattern_take(pattern));
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbutton_punctuation_sentence_structure), bitpattern_take(pattern));
 }
 
 
@@ -275,7 +268,6 @@ void MyChecksDialog::on_okbutton()
   bitpattern_add(pattern, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbutton_markers_spacing)));
   bitpattern_add(pattern, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbutton_references_inventory)));
   bitpattern_add(pattern, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbutton_references_validate)));
-  bitpattern_add(pattern, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbutton_punctuation_sentence_structure)));
   extern Settings *settings;
   settings->genconfig.mychecks_set(pattern);
   // Collect all checking results.
@@ -324,9 +316,6 @@ void MyChecksDialog::on_okbutton()
   if (bitpattern_take(pattern))
     if (keep_going)
       keep_going = scripture_checks_validate_references(NULL, &results);
-  if (bitpattern_take(pattern))
-    if (keep_going)
-      keep_going = scripture_checks_sentence_structure(NULL, &results);
   // Display checking results.
   if (keep_going)
     checks_display_references_comments(results.references, results.comments, my_references_window);
