@@ -35,7 +35,7 @@ ReferenceExchangeDialog::ReferenceExchangeDialog(int dummy)
   Shortcuts shortcuts (0);
   
   gtkbuilder = gtk_builder_new ();
-  gtk_builder_add_from_file (gtkbuilder, gw_build_filename (directories_get_package_data(), "gtkbuilder.referenceexchangedialog.xml").c_str(), NULL);
+  gtk_builder_add_from_file (gtkbuilder, gw_build_filename (Directories->get_package_data(), "gtkbuilder.referenceexchangedialog.xml").c_str(), NULL);
 
   dialog = GTK_WIDGET (gtk_builder_get_object (gtkbuilder, "dialog"));
 
@@ -102,7 +102,8 @@ void ReferenceExchangeDialog::on_url_test_clicked(GtkButton * button, gpointer u
 void ReferenceExchangeDialog::on_url_test()
 {
   GwSpawn spawn ("curl");
-  spawn.arg ("-sS"); // Makes curl silent, but still show errors.
+  // Makes curl silent, no checking of certificate, but still show errors.
+  spawn.arg ("-sSk"); 
   ustring url = gtk_entry_get_text (GTK_ENTRY (entry_url));
   url.append ("/ipc/setmessage.php");
   spawn.arg (url);
