@@ -40,7 +40,7 @@ ShowNotesDialog::ShowNotesDialog(int dummy)
   extern Settings *settings;
 
   gtkbuilder = gtk_builder_new ();
-  gtk_builder_add_from_file (gtkbuilder, gw_build_filename (directories_get_package_data(), "gtkbuilder.showprojectnotesdialog.xml").c_str(), NULL);
+  gtk_builder_add_from_file (gtkbuilder, gw_build_filename (Directories->get_package_data(), "gtkbuilder.showprojectnotesdialog.xml").c_str(), NULL);
 
   dialog = GTK_WIDGET (gtk_builder_get_object (gtkbuilder, "dialog"));
 
@@ -440,7 +440,8 @@ void ShowNotesDialog::restart_timeout ()
   event_id = g_timeout_add_full(G_PRIORITY_DEFAULT, 100, GSourceFunc(on_timeout), gpointer(this), NULL);
 }
 
-
+// MAP: I believe these two routines can be eliminated. Just set the
+// bool on on_timeout is set up.
 bool ShowNotesDialog::on_timeout(gpointer user_data)
 {
   ((ShowNotesDialog *) user_data)->timeout();
