@@ -17,7 +17,6 @@
 **  
 */
 
-
 #include "libraries.h"
 #include "utilities.h"
 #include "export_utils.h"
@@ -58,7 +57,7 @@
 void export_to_usfm (const ustring& project, ustring location, bool zip)
 {
   // (Temporal) output directory.
-  ustring tempdir = gw_build_filename(directories_get_temp(), "usfm-export");
+  ustring tempdir = gw_build_filename(Directories->get_temp(), "usfm-export");
   unix_rmdir(tempdir);
   gw_mkdir_with_parents(tempdir);
   if (!zip)
@@ -90,7 +89,10 @@ void export_to_usfm (const ustring& project, ustring location, bool zip)
     // Progress info.
     progresswindow.iterate();
     vector <ustring> lines = project_retrieve_book(project, books[i]);
-    ustring filename = convert_to_string (books[i]) + " " + books_id_to_english(books[i]) + ".usfm";
+    char padded [3];
+    sprintf (padded, "%02d", books[i]);
+    ustring padded2 (padded);
+    ustring filename = padded2  + " " + books_id_to_english(books[i]) + ".usfm";
     replace_text (filename, " ", "_");
     if (zip)
       filename = gw_build_filename(tempdir, filename);
@@ -109,7 +111,11 @@ void export_to_usfm (const ustring& project, ustring location, bool zip)
 #else
     ustring command = "cd" + shell_quote_space(tempdir) + "; zip -r zip.zip *.usfm; mv zip.zip" + shell_quote_space(location);
 #endif
-    if (system(command.c_str())) ; // This one does not work with GwSpawn because of the wildcards used.
+    // This one does not work with GwSpawn because of the wildcards used.
+    if (int ret = system(command.c_str())) {
+      cerr << "System call for zip and move returned " << ret << endl;
+      cerr << "-1 indicates error; return status of the command otherwise" << endl;
+    } 
   }
 }
 
@@ -546,7 +552,7 @@ directory: Where to put the module.
   ProgressWindow *progresswindow = new ProgressWindow("Exporting project", true);
 
   // The temporal directories for the data.
-  ustring base_directory = gw_build_filename(directories_get_temp(), "sword");
+  ustring base_directory = gw_build_filename(Directories->get_temp(), "sword");
   unix_rmdir(base_directory);
   gw_mkdir_with_parents(base_directory);
   ustring absolute_conf_directory = gw_build_filename(base_directory, "mods.d");
@@ -584,7 +590,7 @@ directory: Where to put the module.
   lines.clear();
 
   // Osis file name.
-  ustring osisfile = gw_build_filename(directories_get_temp(), "osis-from-usfm.xml");
+  ustring osisfile = gw_build_filename(Directories->get_temp(), "osis-from-usfm.xml");
   unlink(osisfile.c_str());
   
   // OSIS to USFM converter.
@@ -718,7 +724,7 @@ void export_to_opendocument(const ustring& project, const ustring& filename)
 void export_to_usfm_changes (const ustring& project, int time_from, ustring comment)
 {
   // Working directory and zipped filename.
-  ustring workingdirectory = gw_build_filename(directories_get_temp(), "bible_backup");
+  ustring workingdirectory = gw_build_filename(Directories->get_temp(), "bible_backup");
   gw_mkdir_with_parents(workingdirectory);
   int currentseconds = date_time_seconds_get_current();
   int currentdays = date_time_julian_day_get_current();
@@ -807,7 +813,7 @@ void export_to_usfm_changes (const ustring& project, int time_from, ustring comm
 
   // Open web page with information: backup_is_ready.html.
   ustring filesize = convert_to_string(file_get_size(filename));
-  ReadText rt(gw_build_filename(directories_get_package_data(), "backup_is_ready.html"), true, false);
+  ReadText rt(gw_build_filename(Directories->get_package_data(), "backup_is_ready.html"), true, false);
   for (unsigned int i = 0; i < rt.lines.size(); i++) {
     replace_text(rt.lines[i], "100", filesize);
     replace_text(rt.lines[i], "location", filename);
@@ -815,7 +821,7 @@ void export_to_usfm_changes (const ustring& project, int time_from, ustring comm
   }
   ustring htmlfile = gw_build_filename(workingdirectory, "backup.html");
   write_lines(htmlfile, rt.lines);
-  unix_cp(gw_build_filename(directories_get_package_data(), "bibledit.css"), gw_build_filename(workingdirectory, "bibledit.css"));
+  unix_cp(gw_build_filename(Directories->get_package_data(), "bibledit.css"), gw_build_filename(workingdirectory, "bibledit.css"));
   gtkw_show_uri (htmlfile, false);
 }
 
@@ -824,7 +830,7 @@ void export_to_go_bible (const ustring& project, const ustring& foldername)
 // Export the project to a full GoBible.
 {
   // Working area directory.
-  ustring workingdirectory = gw_build_filename (directories_get_temp(), "gobible");
+  ustring workingdirectory = gw_build_filename (Directories->get_temp(), "gobible");
   unix_rmdir (workingdirectory);
   gw_mkdir_with_parents (workingdirectory);
   
