@@ -34,7 +34,7 @@
 
 ustring general_configuration_filename()
 {
-  return gw_build_filename(directories_get_configuration(), "configuration.1.xml");
+  return gw_build_filename(Directories->get_configuration(), "configuration.1.xml");
 }
 
 
@@ -201,7 +201,6 @@ GeneralConfiguration::GeneralConfiguration(bool save_on_destroy)
   INITIALIZE(reference_window_show_relevant_bits);
   INITIALIZE(consultation_notes_git_use_remote_repository);
   INITIALIZE(consultation_notes_git_remote_repository_url);
-  INITIALIZE(consultation_notes_git_remote_repository_conflict_handling);
   INITIALIZE(bibledit_web_url);
   INITIALIZE(bibledit_web_user);
 }
@@ -349,7 +348,6 @@ void GeneralConfiguration::save()
   SAVE_VALUE(reference_window_show_relevant_bits);
   SAVE_VALUE(consultation_notes_git_use_remote_repository);
   SAVE_VALUE(consultation_notes_git_remote_repository_url);
-  SAVE_VALUE(consultation_notes_git_remote_repository_conflict_handling);
   SAVE_VALUE(bibledit_web_url);
   SAVE_VALUE(bibledit_web_user);
 
@@ -584,6 +582,5 @@ IMPLEMENT(bool, bool_get, reference_window_show_verse_text, true)
 IMPLEMENT(bool, bool_get, reference_window_show_relevant_bits, false)
 IMPLEMENT(bool, bool_get, consultation_notes_git_use_remote_repository, false)
 IMPLEMENT(ustring, string_get, consultation_notes_git_remote_repository_url, "")
-IMPLEMENT(int, int_get, consultation_notes_git_remote_repository_conflict_handling, 0)
 IMPLEMENT(ustring, string_get, bibledit_web_url, "http://localhost/bibledit")
 IMPLEMENT(ustring, string_get, bibledit_web_user, "")
