@@ -1,5 +1,5 @@
 /*
-** Copyright (©) 2003-2012 Teus Benschop.
+** Copyright (©) 2003-2013 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 
 
 #include "libraries.h"
-#include "htmlbrowser.h" // Todo
+#include "htmlbrowser.h"
 #include "help.h"
 #include "directories.h"
 #include "gwrappers.h"
@@ -119,7 +119,7 @@ void InDialogHelp::on_helpbutton()
   url.append(mytopic);
   url.append(".html");
   
-  htmlbrowser (url, false, true); // Todo
+  htmlbrowser (url, false, true);
   
   // Present the window.
   g_usleep(500000);
