@@ -1,5 +1,5 @@
 /*
-** Copyright (©) 2003-2012 Teus Benschop.
+** Copyright (©) 2003-2013 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 #include "libraries.h"
 
 
-void htmlbrowser (const ustring& filename, bool network = false, bool no_tamper = false); // Todo
+void htmlbrowser (const ustring& filename, bool network = false, bool no_tamper = false);
 ustring html_server_url (const ustring& url);
 
 
