@@ -38,14 +38,14 @@
 ustring keyterms_get_user_filename()
 // Gives the filename for the user-created keyterms database.
 {
-  return gw_build_filename(directories_get_templates_user(), "keyterms.sql");
+  return gw_build_filename(Directories->get_templates_user(), "keyterms.sql");
 }
 
 
 ustring keyterms_get_package_filename()
 // Gives the filename for the keyterms database that comes with bibledit.
 {
-  return gw_build_filename(directories_get_package_data(), "keyterms.sql");
+  return gw_build_filename(Directories->get_package_data(), "keyterms.sql");
 }
 
 
@@ -750,8 +750,7 @@ void keyterms_import_ktbh_txt(const ustring& textfile, ustring category)
       catch(exception & ex) {
         ustring msg = "Skipping: ";
         msg.append(ex.what());
-        if (write(1, msg.c_str(), strlen(msg.c_str()))) ;
-        cout << endl;
+        cout << msg << endl;
       }
 
     }
@@ -1000,7 +999,7 @@ ustring keyterms_renderings_filename(const ustring & project)
 // Returns the filename for the database to store user data.
 // If the database is not there, it will be created on the fly.
 {
-  ustring filename = gw_build_filename(directories_get_projects(), project,
+  ustring filename = gw_build_filename(Directories->get_projects(), project,
                                        "keyterms-renderings.sql");
   if (!g_file_test(filename.c_str(), G_FILE_TEST_IS_REGULAR)) {
     sqlite3 *db;
@@ -1071,7 +1070,12 @@ void keyterms_store_renderings(const ustring & project, const ustring & keyterm,
     rc = sqlite3_exec(db, sql, NULL, NULL, &error);
     g_free(sql);
     for (unsigned int i = 0; i < renderings.size(); i++) {
-      sql = g_strdup_printf("insert into renderings values ('%s', '%s', '%s', %d, %d);", double_apostrophy(keyterm).c_str(), double_apostrophy(collection).c_str(), double_apostrophy(renderings[i]).c_str(), wholewords[i], casesensitives[i]);
+      ustring s1 = double_apostrophy(keyterm);
+      ustring s2 = double_apostrophy(collection);
+      ustring s3 = double_apostrophy(renderings[i]);
+      int i1 = wholewords[i];
+      int i2 = casesensitives[i];
+      sql = g_strdup_printf("insert into renderings values ('%s', '%s', '%s', %d, %d);", s1.c_str(), s2.c_str(), s3.c_str(), i1, i2);
       rc = sqlite3_exec(db, sql, NULL, NULL, &error);
       g_free(sql);
       if (rc)
