@@ -1,5 +1,5 @@
 /*
- ** Copyright (©) 2003-2012 Teus Benschop.
+ ** Copyright (©) 2003-2013 Teus Benschop.
  **  
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -17,14 +17,14 @@
  **  
  */
 
+
 #ifndef INCLUDED_NOTE_EDITOR_H
 #define INCLUDED_NOTE_EDITOR_H
 
+
 #include "libraries.h"
 #include <gtk/gtk.h>
-extern "C" {
-#include <gtkhtml/gtkhtml.h>
-}
+
 
 class NoteEditor
 // Used while a note is being edited.
@@ -41,7 +41,7 @@ public:
   ustring previous_category;
   ustring previous_project;
   void store_original_data (const ustring& data);
-  void receive_data_from_html_editor(const char *data, unsigned int len);
+  void receive_data_from_html_editor (const char *data);
   ustring clean_edited_data();
   bool data_was_edited ();
 private:
@@ -49,11 +49,5 @@ private:
   ustring edited_data;
 };
 
-vector <ustring> note_editor_font_size_names_list ();
-GtkHTMLFontStyle note_editor_font_size_name_to_enum (const ustring& style);
-ustring note_editor_font_size_enum_to_name (GtkHTMLFontStyle style);
-vector <ustring> note_editor_paragraph_style_names_list ();
-GtkHTMLParagraphStyle note_editor_paragraph_style_name_to_enum (const ustring& style);
-ustring note_editor_paragraph_style_enum_to_name (GtkHTMLParagraphStyle style);
 
 #endif
