@@ -94,7 +94,7 @@ comments: The headings the passages fall under, or another comment.
 void OtNtParallels::read(const gchar * filename)
 {
   // Get contents of the data file. Bail out if not there.
-  ustring xmlfilename = gw_build_filename(directories_get_package_data(), filename);
+  ustring xmlfilename = gw_build_filename(Directories->get_package_data(), filename);
   if (!g_file_test(xmlfilename.c_str(), G_FILE_TEST_IS_REGULAR))
     return;
   gchar *contents;
