@@ -70,8 +70,8 @@ void restore_notes (const ustring& unpack_directory, vector <ustring>& feedback)
   }
   
   // If so, move everything into place.
-  unix_rmdir (directories_get_notes ());
-  unix_mv (unpack_directory, directories_get_notes ());
+  unix_rmdir (Directories->get_notes ());
+  unix_mv (unpack_directory, Directories->get_notes ());
 
   // Run upgrade.
   notes_storage_verify();
@@ -108,7 +108,7 @@ void restore_resource (const ustring& unpack_directory, vector <ustring>& feedba
   }
 
   // Find a non-existing directory where to restore the resource to.
-  ustring restore_directory = gw_build_filename (directories_get_resources (), resource);
+  ustring restore_directory = gw_build_filename (Directories->get_resources (), resource);
   while (g_file_test (restore_directory.c_str(), G_FILE_TEST_EXISTS)) {
     restore_directory.append ("1");
   }
@@ -130,8 +130,8 @@ void restore_all_stage_one (const ustring& unpack_directory, vector <ustring>& f
   }
   
   // Move the directory to the temporal place.
-  unix_rmdir (directories_get_restore ());
-  unix_mv (unpack_directory, directories_get_restore ());
+  unix_rmdir (Directories->get_restore ());
+  unix_mv (unpack_directory, Directories->get_restore ());
   
   // Give feedback about what has transpired.
   feedback.push_back ("Everything was restored");
@@ -142,10 +142,10 @@ void restore_all_stage_one (const ustring& unpack_directory, vector <ustring>& f
 void restore_all_stage_two ()
 // Restore everything: second and last stage.
 {
-  if (g_file_test (directories_get_restore ().c_str(), G_FILE_TEST_IS_DIR)) {
+  if (g_file_test (Directories->get_restore ().c_str(), G_FILE_TEST_IS_DIR)) {
     gw_message ("Restoring everything");
-    unix_rmdir (directories_get_root ());
-    unix_mv (directories_get_restore (), directories_get_root ());
+    unix_rmdir (Directories->get_root ());
+    unix_mv (Directories->get_restore (), Directories->get_root ());
   }
 }
 
