@@ -38,7 +38,7 @@ USFMStandard::~USFMStandard()
 void USFMStandard::load()
 {
   // Bail out if the usfm standard is not there.
-  ustring xmlfilename = gw_build_filename(directories_get_package_data(), "usfm.xml");
+  ustring xmlfilename = gw_build_filename(Directories->get_package_data(), "usfm.xml");
   if (!g_file_test(xmlfilename.c_str(), G_FILE_TEST_IS_REGULAR)) {
     gw_critical ("Can't find USFM standard file");
     return;
