@@ -1,5 +1,5 @@
 /*
- ** Copyright (©) 2003-2012 Teus Benschop.
+ ** Copyright (©) 2003-2013 Teus Benschop.
  **  
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -26,11 +26,9 @@
 #include "ustring.h"
 #include "reference.h"
 #include "floatingwindow.h"
-extern "C" {
-#include <gtkhtml/gtkhtml.h>
-}
 #include "htmlwriter2.h"
 #include "editor.h"
+#include <webkit/webkit.h>
 
 
 class WindowCheckKeyterms : public FloatingWindow
@@ -45,6 +43,7 @@ public:
   ustring collection ();
   void reload_collections ();
   vector <Reference> references;
+  void set_fonts ();
 protected:
   GtkWidget *vbox;
 private:
@@ -56,7 +55,7 @@ private:
   GtkWidget *combobox_collection;
   GtkWidget *label_list;
   GtkWidget *scrolledwindow_terms;
-  GtkWidget *htmlview_terms;
+  GtkWidget *webview_terms;
   GtkWidget *treeview_renderings;
 
   // Underlying constructions.
@@ -64,10 +63,9 @@ private:
   GtkTreeSelection *treeselect_renderings;
 
   // Callbacks.
-  static gboolean on_html_link_clicked(GtkHTML *html, const gchar * url, gpointer user_data);
-  void html_link_clicked(const gchar * url);
-  static void on_html_submit (GtkHTML *html, const gchar *method, const gchar *url, const gchar *encoding, gpointer user_data);
-  void html_submit (const gchar *method, const gchar *url, const gchar *encoding);
+  static gboolean on_navigation_policy_decision_requested (WebKitWebView *web_view, WebKitWebFrame *frame, WebKitNetworkRequest *request, WebKitWebNavigationAction *navigation_action, WebKitWebPolicyDecision *policy_decision, gpointer user_data);
+  void navigation_policy_decision_requested (WebKitNetworkRequest *request, WebKitWebNavigationAction *navigation_action, WebKitWebPolicyDecision *policy_decision);
+  void html_link_clicked (const gchar * url);
   static void on_combobox_keyterm_collection_changed(GtkComboBox *combobox, gpointer user_data);
   static void keyterm_whole_word_toggled(GtkCellRendererToggle *cell, gchar *path_str, gpointer data);
   static void keyterm_case_sensitive_toggled(GtkCellRendererToggle *cell, gchar *path_str, gpointer data);
