@@ -76,7 +76,8 @@ void WindowsOutpost::Start()
 // This effectually starts the whole system.
 {
   thread_run = true;
-  g_thread_new ("windowsoutpost", GThreadFunc(thread_start), gpointer(this));
+  // New g_thread_new ("windowsoutpost", GThreadFunc(thread_start), gpointer(this));
+  g_thread_create (GThreadFunc(thread_start), gpointer(this), false, NULL);
 }
 
 
@@ -585,7 +586,7 @@ ustring windowsoutpost_path ()
 // Gives the full path to the bwoutpost.exe
 {
   ustring path;
-  path = gw_build_filename (directories_get_package_data (), BIBLEDIT_WINDOWS_OUTPOST_EXE);
+  path = gw_build_filename (Directories->get_package_data (), BIBLEDIT_WINDOWS_OUTPOST_EXE);
   return path;
 }
 
