@@ -24,7 +24,7 @@
 TimedNotifierWindow::TimedNotifierWindow(const gchar * notification)
 {
   gtkbuilder = gtk_builder_new ();
-  gtk_builder_add_from_file (gtkbuilder, gw_build_filename (directories_get_package_data(), "gtkbuilder.timednotifywindow.xml").c_str(), NULL);
+  gtk_builder_add_from_file (gtkbuilder, gw_build_filename (Directories->get_package_data(), "gtkbuilder.timednotifywindow.xml").c_str(), NULL);
   window = GTK_WIDGET (gtk_builder_get_object (gtkbuilder, "window"));
   label = GTK_WIDGET (gtk_builder_get_object (gtkbuilder, "label"));
 
@@ -50,6 +50,8 @@ gboolean TimedNotifierWindow::on_delete_event(GtkWidget * widget, GdkEvent * eve
   return true;
 }
 
+// MAP: I believe these two routines can be eliminated. Just do the
+// work where on_timeout is set up.
 gboolean TimedNotifierWindow::on_timeout(gpointer data)
 {
   return ((TimedNotifierWindow *) data)->timeout();
